tui

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrAborted = errors.New("user aborted")

Functions

func Run

func Run(commits []*parser.ParsedCommit, configuration *cfg.Config) ([]*parser.ParsedCommit, error)

Run launches the interactive terminal UI. It takes the commits found by the parser and the loaded config. It returns the final, curated list of commits that the user has approved. Returns an error if the user aborts the session.

Types

This section is empty.

Jump to