Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrAborted = errors.New("user aborted")
Functions ¶
func Run ¶
func Run(commits []*parser.ParsedCommit, configuration *cfg.Config) ([]*parser.ParsedCommit, error)
Run launches the interactive terminal UI. It takes the commits found by the parser and the loaded config. It returns the final, curated list of commits that the user has approved. Returns an error if the user aborts the session.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.